@@ -1,11 +1,9 @@
 var classpw__pipewire =
 [
     [ "pw_debug_is_category_enabled", "classpw__pipewire.html#a5b1fdbfdb5c1ca94d55aa3d658a82432", null ],
-    [ "pw_direction_reverse", "classpw__pipewire.html#a4efeba27bea1dc8d9188b8e49b3bd1b0", null ],
-    [ "pw_fill_remote_properties", "classpw__pipewire.html#aaa9f7d9822aeae824c0e006d34b926f5", null ],
-    [ "pw_fill_stream_properties", "classpw__pipewire.html#a841dbb7608dc9cdda4a320d33fbbd39a", null ],
+    [ "pw_direction_reverse", "classpw__pipewire.html#a9d9479e374690765eb875840b450b371", null ],
     [ "pw_get_application_name", "classpw__pipewire.html#a4a8a07aaab379c3328a0ee2947568533", null ],
-    [ "pw_get_client_name", "classpw__pipewire.html#acd425ab10890b1e758dc55e5aeda6625", null ],
+    [ "pw_get_client_name", "classpw__pipewire.html#ab4288fc1500029d1f471340553f14837", null ],
     [ "pw_get_host_name", "classpw__pipewire.html#a23c220dfb9180f6f26b554673e9e74e2", null ],
     [ "pw_get_prgname", "classpw__pipewire.html#a759b26f6770aac6dc9515e3e6e29049a", null ],
     [ "pw_get_user_name", "classpw__pipewire.html#afd4e195c9b1c8b5dd0d088b3d7b32b64", null ],
