@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"link_8h.html#aa90bcda1ac9edbb5f2c92703f1e38d84":[11,0,37,14],
+"link_8h.html#aafb6d5e113016baef0cf9a8cc9405c31":[11,0,37,10],
+"link_8h.html#ab53c62332a757ed234d5eb91a54a23ac":[11,0,37,3],
 "link_8h_source.html":[11,0,37],
 "log_8c.html":[11,0,38],
 "log_8c.html#a0c36ced32d7c93e93a7546e6b95ab79e":[11,0,38,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX4 =
 "pipewire_8c.html#a5432ea68283040ae9df24ebefe6414aa":[11,0,50,5],
 "pipewire_8c.html#aa060eea150eca4951bf30b2738493912":[11,0,50,8],
 "pipewire_8c.html#ac0edd7fd875859cef79624861e212cc8":[11,0,50,7],
-"pipewire_8c.html#acbb97d3ccaef2d8793ec48242324bf15":[11,0,50,10],
-"pipewire_8c.html#ad6b599f28dfb2e60a14ac4cf01d4c18c":[11,0,50,9],
-"pipewire_8c.html#ae55b0f7a82aa61d5eb34593565176036":[11,0,50,4],
-"pipewire_8h.html":[11,0,51]
+"pipewire_8c.html#acbb97d3ccaef2d8793ec48242324bf15":[11,0,50,10]
 };
