@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"structpw__impl__client__events.html#a046e956441b5395308c8ff140292dfee":[10,0,42,0],
+"structpw__impl__client__events.html#a30be6d32c40038f0ae9dfdbccdf74e1b":[10,0,42,7],
+"structpw__impl__client__events.html#a3e42dd29cba77e524cf6328d006e2b9e":[10,0,42,4],
+"structpw__impl__client__events.html#a59d0c58fc080957b72648c77155782a1":[10,0,42,5],
 "structpw__impl__client__events.html#a64120718bec833fc87ca30ff85e01645":[10,0,42,3],
 "structpw__impl__client__events.html#a7aee6a7b912b1a37032a3a6a156def9d":[10,0,42,1],
 "structpw__impl__client__events.html#a7cc746f92f5d5b8aacf5d9cd278ea575":[10,0,42,2],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14":[10,0,92,0],
 "structpw__proxy__events.html#aaa8802aa5a62fdc422f8db0d606adac3":[10,0,92,1],
 "structpw__proxy__events.html#af8e0510a58d92ddd0831293e1c42b867":[10,0,92,3],
-"structpw__registry__events.html":[10,0,93],
-"structpw__registry__events.html#a3fa28cf2cd3ed8739debec5bb17ace61":[10,0,93,1],
-"structpw__registry__events.html#a94464d7de86207e80a3dff93974b1a01":[10,0,93,2],
-"structpw__registry__events.html#a9a62b37a711f65f1014cb27b92ae2689":[10,0,93,0],
-"structpw__registry__methods.html":[10,0,94]
+"structpw__registry__events.html":[10,0,93]
 };
